<?php

namespace Goldenscarab\Modulus\Service\Field;


use Illuminate\Support\Facades\Request;
use Goldenscarab\Modulus\Service\Field\Compose\Field2Bt4 as FieldBt4;


class Field2
{

    /**
     * Retourne un champs code source
     *
     * @param array $attrs Attributs du champs
     * @return string Le HTML du champs code source
     */
    public function code($attrs): string
    {
        $field  = new FieldBt4($attrs);
        $code   = $field->renderCodeEditor();
        $render = $field->renderWrapFieldEnvironment($code, true);

        return $field->renderHTML($render);
    }

    /**
     * Retourne un champs select de choix de publication
     * @param  boolean $status La valeur du champs
     * @return string Le HTML du champs de publication
     */
    public function publish($status): string
    {
        $render = $this->select([
            'label'      => 'Visibilité',
            'name'       => 'status',
            'prefix'     => '<i class="fa fa-globe"></i>',
            'value'      => $status,
            'attributes' => ['required' => true],
            'options'    => ['source' => [0 => 'Brouillon', 1 => 'En ligne']]
        ]);

        return $render;
    }

    /**
     * Retourne un champs de recherche dans une liste
     * @return string Le HTML du champs de recherche
     */
    public function search(): string
    {
        $render = $this->input([
            'name'        => 'search',
            'value'       => Request::get('search'),
            'attributes'  => [
                'placeholder' => 'Recherche...',
                'class'       => 'form-control-sm',
            ],
            'suffix'      => '<button class="btn btn-outline-secondary btn-sm" type="submit" id="button-search"><i class="fa fa-search"></i></button>',
        ]);

        return $render;
    }

    /**
     * Retourne un champs select pour choisir le nombre d'éléments d'une liste à afficher
     * @return string Le HTML du menu déroulant
     */
    public function perpage(): string
    {
        $render = $this->select([
            'label'      => 'Lignes par page',
            'value'      => Request::fullUrlWithQuery(["perpage" => Request::get('perpage')]),
            'attributes' => [
                'class'       => 'ml-2',
                'placeholder' => 'Choisir...',
                'onchange'    => 'return document.location.href = this.value;'
            ],
            'options' => [
                'source' => [
                    Request::fullUrlWithQuery(["perpage" => 10])   => '10',
                    Request::fullUrlWithQuery(["perpage" => 15])   => '15',
                    Request::fullUrlWithQuery(["perpage" => 50])   => '50',
                    Request::fullUrlWithQuery(["perpage" => 100])  => '100',
                    Request::fullUrlWithQuery(["perpage" => 200])  => '200',
                    Request::fullUrlWithQuery(["perpage" => 500])  => '500',
                    Request::fullUrlWithQuery(["perpage" => 1000]) => '1000'
                ]
            ]
        ]);

        return $render;
    }

    /**
     * Retourne un champs file avec son environnement
     * @param  array  $attrs Les attributs du champs
     * @return string        le HTML du champs et de son environnement
     */
    public function file($attrs = []): string
    {
        $field  = new FieldBt4($attrs);
        $file  = $field->renderFile();
        $render = $field->renderWrapFieldEnvironment($file);

        return $field->renderHTML($render);
    }

    /**
     * Retourne un champs pdf avec son environnement
     * @param  array  $attrs Les attributs du champs
     * @return string        le HTML du champs et de son environnement
     */
    public function pdf($attrs = []): string
    {
        $field  = new FieldBt4($attrs);
        $image  = $field->renderPdf();
        $render = $field->renderWrapFieldEnvironment($image);

        return $field->renderHTML($render);
    }

    /**
     * Retourne un champs video avec son environnement
     * @param  array  $attrs Les attributs du champs
     * @return string        le HTML du champs et de son environnement
     */
    public function video($attrs = []): string
    {
        $field  = new FieldBt4($attrs);
        $image  = $field->renderVideo();
        $render = $field->renderWrapFieldEnvironment($image);

        return $field->renderHTML($render);
    }

    /**
     * Retourne un champs image avec son environnement
     * @param  array  $attrs Les attributs du champs
     * @return string        le HTML du champs et de son environnement
     */
    public function image($attrs = []): string
    {
        $field  = new FieldBt4($attrs);
        $image  = $field->renderImage();
        $render = $field->renderWrapFieldEnvironment($image);

        return $field->renderHTML($render);
    }

    /**
     * Retourne un champs dossier avec son environnement
     * @param  array  $attrs Les attributs du champs
     * @return string        le HTML du champs et de son environnement
     */
    public function folder($attrs = []): string
    {
        $field  = new FieldBt4($attrs);
        $folder = $field->renderFolder();
        $render = $field->renderWrapFieldEnvironment($folder);

        return $field->renderHTML($render);
    }

    /**
     * Retourne un champs toggle avec son environnement
     * @param  array  $attrs Les attributs du champs
     * @return string        Le HTML du champs et de son environnement
     */
    public function toggle($attrs = []): string
    {
        $field  = new FieldBt4($attrs);
        $toggle = $field->renderToggle();
        $render = $field->renderWrapFieldEnvironment($toggle);

        return $field->renderHTML($render);
    }

    /**
     * Retourne un champs radio avec son environnement
     * @param  array  $attrs Les attributs du champs
     * @return string        Le HTML du champs et de son environnement
     */
    public function radio($attrs = []): string
    {
        $field  = new FieldBt4($attrs);
        $radio  = $field->renderRadio();
        $render = $field->renderWrapFieldEnvironment($radio);

        return $field->renderHTML($render);
    }

    /**
     * Retourne un champs checkbox avec son environnement
     * @param  array  $attrs Les attributs du champs
     * @return string        Le HTML du champs et de son environnement
     */
    public function checkbox($attrs = []): string
    {
        $field    = new FieldBt4($attrs);
        $checkbox = $field->renderCheckbox();
        $render   = $field->renderWrapFieldEnvironment($checkbox);

        return $field->renderHTML($render);
    }

    /**
     * Retourne un champs range avec son environnement
     * @param  array  $attrs Les attributs du champs
     * @return string        Le HTML du champs et de son environnement
     */
    public function range($attrs = []): string
    {
        $field  = new FieldBt4($attrs);
        $range  = $field->renderRange();
        $render = $field->renderWrapFieldEnvironment($range);

        return $field->renderHTML($render);
    }

    /**
     * Retourne un champs pot de miel avec son environnement
     * @return string Le HTML du champs et son environnement
     */
    public function honeypot(): string
    {
        $field  = new FieldBt4([
            'name'       => 'my-name',
            'attributes' => ['class' => 'd-none']
        ]);
        $input1  = $field->renderInput();

        $field  = new FieldBt4([
            'name'       => 'my-time',
            'value'      => encrypt(time()),
            'attributes' => ['class' => 'd-none']
        ]);
        $input2  = $field->renderInput();

        return $field->renderHTML($input1 . $input2);
    }

    /**
     * Retourne un champs textarea avec son environnement
     * @param  array $attrs Les attributs du champs
     * @return string       Le HTML du champs et de son environnement
     */
    public function textarea($attrs = []): string
    {
        $field    = new FieldBt4($attrs);
        $textarea = $field->renderTextarea();
        $render   = $field->renderWrapFieldEnvironment($textarea, true);

        return $field->renderHTML($render);
    }

    /**
     * Retourne un champs select avec son environnement
     * @param  array $attrs Les attributs du champs
     * @return string       Le HTML du champs et de son environnement
     */
    public function select($attrs = []): string
    {
        $field  = new FieldBt4($attrs);
        $select = $field->renderSelect();
        $render = $field->renderWrapFieldEnvironment($select);

        return $field->renderHTML($render);
    }

    /**
     * Retourne un champs input avec son environnement
     * @param  array $attrs  Les attributs du champs
     * @return string        Le HTML du champs et de son environnement
     */
    public function input($attrs = []): string
    {
        $field  = new FieldBt4($attrs);
        $input  = $field->renderInput();
        $render = $field->renderWrapFieldEnvironment($input);

        return $field->renderHTML($render);
    }

}
